@@ -910,6 +910,18 @@ class SVG:
             shape.round_floats(ndigits, inplace=True)
         return self
 
+    def remove_empty_subpaths(self, inplace=False):
+        if not inplace:
+            svg = SVG(copy.deepcopy(self.svg_root))
+            svg.remove_empty_subpaths(inplace=True)
+            return svg
+
+        for shape in self.shapes():
+            if isinstance(shape, SVGPath):
+                shape.remove_empty_subpaths(inplace=True)
+
+        return self
+
     def remove_unpainted_shapes(self, inplace=False):
         if not inplace:
             svg = SVG(copy.deepcopy(self.svg_root))
@@ -1321,6 +1333,7 @@ class SVG:
 
         # Tidy up
         self.evenodd_to_nonzero_winding(inplace=True)
+        self.remove_empty_subpaths(inplace=True)
         self.remove_unpainted_shapes(inplace=True)
         self.normalize_opacity(inplace=True)
         self.absolute(inplace=True)
@@ -1429,6 +1442,15 @@ def _inherit_nondefault_overflow(attrib, child, attr_name):
         _inherit_copy(attrib, child, attr_name)
 
 
+# https://github.com/googlefonts/picosvg/issues/260
+def _inherit_nondefault_display(attrib, child, attr_name):
+    value = attrib.get(attr_name, "")
+    if value == "none":
+        child.attrib[attr_name] = value
+    else:
+        _inherit_copy(attrib, child, attr_name)
+
+
 def _inherit_matrix_multiply(attrib, child, attr_name):
     transform = Affine2D.identity()
     if attr_name in attrib:
@@ -1450,7 +1472,7 @@ def _do_not_inherit(*_):
 _INHERIT_ATTRIB_HANDLERS = {
     "clip-rule": _inherit_copy,
     "color": _inherit_copy,
-    "display": _inherit_copy,
+    "display": _inherit_nondefault_display,
     "fill": _inherit_copy,
     "fill-rule": _inherit_copy,
     "style": _inherit_copy,
@@ -1514,7 +1536,9 @@ def _inherit_attrib(
     skip_unhandled: bool = False,
     skips=frozenset(),
 ):
-    attrib = copy.deepcopy(attrib)
+    attrib: MutableMapping[str, Any] = copy.deepcopy(
+        attrib
+    )  # pytype: disable=annotation-type-mismatch
     for attr_name in sorted(attrib.keys()):
         if attr_name in skips or not _attr_supported(child, attr_name):
             del attrib[attr_name]
