@@ -271,6 +271,16 @@ def test_resolve_use(actual, expected_result):
             "inherit-default-fill-before.svg",
             "inherit-default-fill-nano.svg",
         ),
+        # propagation of display:none
+        (
+            "display_none-before.svg",
+            "display_none-nano.svg",
+        ),
+        # https://github.com/googlefonts/picosvg/issues/252
+        (
+            "strip_empty_subpath-before.svg",
+            "strip_empty_subpath-nano.svg",
+        ),
     ],
 )
 def test_topicosvg(actual, expected_result):
